==> haskell-tagstream-conduit-0.5.6-366-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tagstream-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tagstream-conduit
version:              0.5.6
visibility:           public
id:                   tagstream-conduit-0.5.6-4GNBHabqYGa9t8CbHX3WNc
key:                  tagstream-conduit-0.5.6-4GNBHabqYGa9t8CbHX3WNc
license:              BSD-3-Clause
maintainer:           yi.codeplayer@gmail.com
author:               yihuang
homepage:             http://github.com/yihuang/tagstream-conduit
synopsis:             streamlined html tag parser
description:
    Tag-stream is a library for parsing HTML//XML to a token stream.
    It can parse unstructured and malformed HTML from the web.
    It also provides an Enumeratee which can parse streamline html, which means it consumes constant memory.
    You can start from the `tests/Tests.hs` module to see what it can do.

category:             Web, Conduit
abi:                  6ee67236a49b8cafb3e50ae4af348e64
exposed:              True
exposed-modules:
    Text.HTML.TagStream Text.HTML.TagStream.ByteString
    Text.HTML.TagStream.Entities Text.HTML.TagStream.Text
    Text.HTML.TagStream.Types Text.HTML.TagStream.Utils

import-dirs:          /usr/lib/ghc-9.2.8/site-local/tagstream-conduit-0.5.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tagstream-conduit-0.5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tagstream-conduit
hs-libraries:         HStagstream-conduit-0.5.6-4GNBHabqYGa9t8CbHX3WNc
depends:
    attoparsec-0.14.4-l6gpYVAuXa4krkAJlMwbn base-4.16.4.0
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    case-insensitive-1.2.1.0-2Tjf2PFkxP43DkqVUMYCmf
    conduit-1.3.5-9fqCSsgtXVG2zpv5ZVEi4s
    conduit-extra-1.3.6-AEwfYIT97IN5iosArwGxsb
    data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB
    resourcet-1.2.6-L3rnNUXQIyNIGkCgFQVXFM text-1.2.5.0
    transformers-0.5.6.2 xml-conduit-1.9.1.3-78hprMCLgMFFWPQU2FN158

haddock-interfaces:
    /usr/share/doc/haskell-tagstream-conduit/html/tagstream-conduit.haddock

haddock-html:         /usr/share/doc/haskell-tagstream-conduit/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tagstream-conduit-0.5.6-380-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tagstream-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tagstream-conduit
version:              0.5.6
visibility:           public
id:                   tagstream-conduit-0.5.6-KUDCONQY8bN4ag8sp4c7Tn
key:                  tagstream-conduit-0.5.6-KUDCONQY8bN4ag8sp4c7Tn
license:              BSD-3-Clause
maintainer:           yi.codeplayer@gmail.com
author:               yihuang
homepage:             http://github.com/yihuang/tagstream-conduit
synopsis:             streamlined html tag parser
description:
    Tag-stream is a library for parsing HTML//XML to a token stream.
    It can parse unstructured and malformed HTML from the web.
    It also provides an Enumeratee which can parse streamline html, which means it consumes constant memory.
    You can start from the `tests/Tests.hs` module to see what it can do.

category:             Web, Conduit
abi:                  16c8f446304b0db8dae54dfd7aaf0ebf
exposed:              True
exposed-modules:
    Text.HTML.TagStream Text.HTML.TagStream.ByteString
    Text.HTML.TagStream.Entities Text.HTML.TagStream.Text
    Text.HTML.TagStream.Types Text.HTML.TagStream.Utils

import-dirs:          /usr/lib/ghc-9.2.8/site-local/tagstream-conduit-0.5.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tagstream-conduit-0.5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tagstream-conduit
hs-libraries:         HStagstream-conduit-0.5.6-KUDCONQY8bN4ag8sp4c7Tn
depends:
    attoparsec-0.14.4-7zFXPvsAeTc17D9FbG47Bq base-4.16.4.0
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    case-insensitive-1.2.1.0-6AqTtfG0yj5cd4BFV01sh
    conduit-1.3.6-6d8V4DJENsC1laAutlfv9x
    conduit-extra-1.3.6-GQSgUNMr0ZN9ENRzkRi4eD
    data-default-0.7.1.1-JYvfHll1aet2HYdPlRdwv9
    resourcet-1.2.6-KSYfCEph27i1WbA0p8CCrD text-1.2.5.0
    transformers-0.5.6.2 xml-conduit-1.9.1.3-AwLhlaz27ql1567v7tH4L6

haddock-interfaces:
    /usr/share/doc/haskell-tagstream-conduit/html/tagstream-conduit.haddock

haddock-html:         /usr/share/doc/haskell-tagstream-conduit/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
